@@ -755,25 +755,72 @@ impl Pure<'_> {
         }
 
         if self.options.side_effects && self.options.pristine_globals {
-            if let Expr::New(NewExpr { callee, args, .. }) = e {
-                if let Expr::Ident(i) = &**callee {
-                    match &*i.sym {
-                        "Map" | "Set" | "Array" | "Object" | "Boolean" | "Number" => {
-                            if i.span.ctxt.outer() == self.marks.unresolved_mark {
-                                report_change!("Dropping a pure new expression");
+            match e {
+                Expr::New(NewExpr { callee, args, .. }) => {
+                    if let Expr::Ident(i) = &**callee {
+                        match &*i.sym {
+                            "Map" | "Set" | "Array" | "Object" | "Boolean" | "Number" => {
+                                if i.span.ctxt.outer() == self.marks.unresolved_mark {
+                                    report_change!("Dropping a pure new expression");
 
-                                self.changed = true;
-                                *e = self
-                                    .make_ignored_expr(
-                                        args.iter_mut().flatten().map(|arg| arg.expr.take()),
-                                    )
-                                    .unwrap_or(Expr::Invalid(Invalid { span: DUMMY_SP }));
-                                return;
+                                    self.changed = true;
+                                    *e = self
+                                        .make_ignored_expr(
+                                            args.iter_mut().flatten().map(|arg| arg.expr.take()),
+                                        )
+                                        .unwrap_or(Expr::Invalid(Invalid { span: DUMMY_SP }));
+                                    return;
+                                }
                             }
+                            _ => {}
                         }
-                        _ => {}
                     }
                 }
+
+                // terser compiles
+                //
+                //  [1,foo(),...bar()][{foo}]
+                //
+                // as
+                //
+                //  foo(),basr(),foo;
+                Expr::Member(MemberExpr {
+                    obj,
+                    prop: MemberProp::Computed(prop),
+                    ..
+                }) => {
+                    let mut exprs = vec![];
+
+                    if let Expr::Array(obj_arr) = &mut **obj {
+                        //
+
+                        for ExprOrSpread { mut expr, .. } in
+                            obj_arr.elems.take().into_iter().flatten()
+                        {
+                            self.ignore_return_value(
+                                &mut expr,
+                                DropOpts {
+                                    drop_str_lit: true,
+                                    drop_zero: true,
+                                    drop_global_refs_if_unused: true,
+                                    ..opts
+                                },
+                            );
+                            if !expr.is_invalid() {
+                                exprs.push(expr);
+                            }
+                        }
+
+                        exprs.push(prop.expr.take());
+
+                        *e = self
+                            .make_ignored_expr(exprs.into_iter())
+                            .unwrap_or(Expr::Invalid(Invalid { span: DUMMY_SP }));
+                        self.changed = true;
+                        return;
+                    }
+                }
+                _ => {}
             }
         }
 
